==> zarm-3.1.3.tgz: package/es/modal/Alert.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _regeneratorRuntime from "@babel/runtime/regenerator";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import { createBEM } from '@zarm-design/bem';
import { getRuntimeConfig } from '../config-provider';
import { show } from './methods';
export var alert = function alert(props) {
  var className = props.className,
      _props$animationType = props.animationType,
      animationType = _props$animationType === void 0 ? 'zoom' : _props$animationType,
      confirmText = props.confirmText,
      onConfirm = props.onConfirm,
      rest = _objectWithoutProperties(props, ["className", "animationType", "confirmText", "onConfirm"]);

  var _getRuntimeConfig = getRuntimeConfig(),
      prefixCls = _getRuntimeConfig.prefixCls,
      locale = _getRuntimeConfig.locale;

  var bem = createBEM('alert', {
    prefixCls: prefixCls
  });
  return new Promise(function (resolve) {
    var _show = show(_objectSpread(_objectSpread({}, rest), {}, {
      className: bem([className]),
      animationType: animationType,
      actions: [{
        text: confirmText || (locale === null || locale === void 0 ? void 0 : locale.Modal.confirmText),
        onClick: function () {
          var _onClick = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
            var _props$onConfirm;

            var result;
            return _regeneratorRuntime.wrap(function _callee$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    _context.next = 2;
                    return (_props$onConfirm = props.onConfirm) === null || _props$onConfirm === void 0 ? void 0 : _props$onConfirm.call(props);

                  case 2:
                    result = _context.sent;

                    if (!(result === false)) {
                      _context.next = 5;
                      break;
                    }

                    return _context.abrupt("return");

                  case 5:
                    close();
                    resolve(null);

                  case 7:
                  case "end":
                    return _context.stop();
                }
              }
            }, _callee);
          }));

          function onClick() {
            return _onClick.apply(this, arguments);
          }

          return onClick;
        }()
      }]
    })),
        close = _show.close;
  });
};
export default alert;

==> zarm-3.3.1.tgz: package/es/modal/Alert.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _regeneratorRuntime from "@babel/runtime/regenerator";

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }

function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }

import { createBEM } from '@zarm-design/bem';
import { getRuntimeConfig } from '../config-provider';
import { show } from './methods';
export var alert = function alert(props) {
  var className = props.className,
      _props$animationType = props.animationType,
      animationType = _props$animationType === void 0 ? 'zoom' : _props$animationType,
      confirmText = props.confirmText,
      onConfirm = props.onConfirm,
      rest = _objectWithoutProperties(props, ["className", "animationType", "confirmText", "onConfirm"]);

  var _getRuntimeConfig = getRuntimeConfig(),
      prefixCls = _getRuntimeConfig.prefixCls,
      locale = _getRuntimeConfig.locale;

  var bem = createBEM('alert', {
    prefixCls: prefixCls
  });
  return new Promise(function (resolve) {
    var _show = show(_objectSpread(_objectSpread({}, rest), {}, {
      className: bem([className]),
      animationType: animationType,
      actions: [{
        text: confirmText || (locale === null || locale === void 0 ? void 0 : locale.Modal.confirmText),
        onClick: function () {
          var _onClick = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
            var _props$onConfirm;

            var result;
            return _regeneratorRuntime.wrap(function _callee$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    _context.next = 2;
                    return (_props$onConfirm = props.onConfirm) === null || _props$onConfirm === void 0 ? void 0 : _props$onConfirm.call(props);

                  case 2:
                    result = _context.sent;

                    if (!(result === false)) {
                      _context.next = 5;
                      break;
                    }

                    return _context.abrupt("return");

                  case 5:
                    close();
                    resolve(null);

                  case 7:
                  case "end":
                    return _context.stop();
                }
              }
            }, _callee);
          }));

          function onClick() {
            return _onClick.apply(this, arguments);
          }

          return onClick;
        }()
      }]
    })),
        close = _show.close;
  });
};
export default alert;
